@@ -19,13 +19,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, 
  * Boston, MA 02111-1307, USA.
  */
-
+ 
 /*
  * Modified by the gtranslator Team, 2006. See the AUTHORS file for a 
  * list of people on the gtranslator Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: history-entry.h 5931 2007-09-25 20:05:40Z pborelli $
+ * $Id$
  */
 
 #ifndef __GTR_HISTORY_ENTRY_H__
@@ -33,68 +33,64 @@
 
 
 G_BEGIN_DECLS
+
 #define GTR_TYPE_HISTORY_ENTRY             (gtranslator_history_entry_get_type ())
 #define GTR_HISTORY_ENTRY(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTR_TYPE_HISTORY_ENTRY, GtranslatorHistoryEntry))
 #define GTR_HISTORY_ENTRY_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GTR_TYPE_HISTORY_ENTRY, GtranslatorHistoryEntryClass))
 #define GTR_IS_HISTORY_ENTRY(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTR_TYPE_HISTORY_ENTRY))
 #define GTR_IS_HISTORY_ENTRY_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTR_TYPE_HISTORY_ENTRY))
 #define GTR_HISTORY_ENTRY_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTR_TYPE_HISTORY_ENTRY, GtranslatorHistoryEntryClass))
-typedef struct _GtranslatorHistoryEntry GtranslatorHistoryEntry;
-typedef struct _GtranslatorHistoryEntryClass GtranslatorHistoryEntryClass;
+
+
+typedef struct _GtranslatorHistoryEntry        GtranslatorHistoryEntry;
+typedef struct _GtranslatorHistoryEntryClass   GtranslatorHistoryEntryClass;
 typedef struct _GtranslatorHistoryEntryPrivate GtranslatorHistoryEntryPrivate;
 
 struct _GtranslatorHistoryEntryClass
 {
-  GtkComboBoxEntryClass parent_class;
+	GtkComboBoxEntryClass parent_class;
 };
 
 struct _GtranslatorHistoryEntry
 {
-  GtkComboBoxEntry parent_instance;
+	GtkComboBoxEntry parent_instance;
 
-  GtranslatorHistoryEntryPrivate *priv;
+	GtranslatorHistoryEntryPrivate *priv;
 };
 
-GType
-gtranslator_history_entry_get_type (void)
-  G_GNUC_CONST;
+GType		 gtranslator_history_entry_get_type	(void) G_GNUC_CONST;
 
-     GtkWidget *gtranslator_history_entry_new (const gchar * history_id,
-					       gboolean enable_completion);
+GtkWidget	*gtranslator_history_entry_new		(const gchar       *history_id,
+							 gboolean           enable_completion);
 
-     void gtranslator_history_entry_prepend_text (GtranslatorHistoryEntry *
-						  entry, const gchar * text);
+void		 gtranslator_history_entry_prepend_text	(GtranslatorHistoryEntry *entry,
+							 const gchar       *text);
 
-     void gtranslator_history_entry_append_text (GtranslatorHistoryEntry *
-						 entry, const gchar * text);
+void		 gtranslator_history_entry_append_text	(GtranslatorHistoryEntry *entry,
+							 const gchar       *text);
 
-     void gtranslator_history_entry_clear (GtranslatorHistoryEntry * entry);
+void		 gtranslator_history_entry_clear		(GtranslatorHistoryEntry *entry);
 
-     void
-       gtranslator_history_entry_set_history_length (GtranslatorHistoryEntry *
-						     entry, guint max_saved);
+void		 gtranslator_history_entry_set_history_length	(GtranslatorHistoryEntry *entry,
+							 guint              max_saved);
 
-     guint
-       gtranslator_history_entry_get_history_length (GtranslatorHistoryEntry *
-						     gentry);
+guint		 gtranslator_history_entry_get_history_length	(GtranslatorHistoryEntry *gentry);
 
-     gchar *gtranslator_history_entry_get_history_id (GtranslatorHistoryEntry
-						      * entry);
+gchar		*gtranslator_history_entry_get_history_id	(GtranslatorHistoryEntry *entry);
 
-     void gtranslator_history_entry_set_enable_completion
-       (GtranslatorHistoryEntry * entry, gboolean enable);
+void             gtranslator_history_entry_set_enable_completion 
+							(GtranslatorHistoryEntry *entry,
+							 gboolean           enable);
+							 
+gboolean         gtranslator_history_entry_get_enable_completion 
+							(GtranslatorHistoryEntry *entry);
 
-     gboolean gtranslator_history_entry_get_enable_completion
-       (GtranslatorHistoryEntry * entry);
+GtkWidget	*gtranslator_history_entry_get_entry		(GtranslatorHistoryEntry *entry);
 
-     GtkWidget *gtranslator_history_entry_get_entry (GtranslatorHistoryEntry *
-						     entry);
-
-     typedef gchar *(*GtranslatorHistoryEntryEscapeFunc) (const gchar * str);
-     void gtranslator_history_entry_set_escape_func (GtranslatorHistoryEntry *
-						     entry,
-						     GtranslatorHistoryEntryEscapeFunc
-						     escape_func);
+typedef gchar * (* GtranslatorHistoryEntryEscapeFunc) (const gchar *str);
+void		gtranslator_history_entry_set_escape_func	(GtranslatorHistoryEntry *entry,
+							 GtranslatorHistoryEntryEscapeFunc escape_func);
 
 G_END_DECLS
+
 #endif /* __GTR_HISTORY_ENTRY_H__ */
